@@ -26,10 +26,10 @@
 #
 
 
-
 import base64
 import json
 import datetime
+import logging
 import argtoolbox
 from requests import Request
 
@@ -40,12 +40,14 @@ from linshareapi.core import LinShareException
 import linsharecli.common.core as common
 
 
-
 class DefaultCommand(common.DefaultCommand):
     """ Default command object use by the serer API. If you want to add a new
     command to the command line interface, your class should extend this class.
     """
 
+    IDENTIFIER = "name"
+    RESOURCE_IDENTIFIER = "uuid"
+
     def __get_cli_object(self, args):
         api_version = self.config.server.api_version.value
         self.log.debug("using api version : " + str(api_version))
@@ -55,13 +57,14 @@ class DefaultCommand(common.DefaultCommand):
         self.log.debug("password: %s...", password[0:2])
         if auth_type == "plain-b64":
             if password:
-                self.log.debug("converting base64 encoded password to plain text.")
+                self.log.debug(
+                        "converting base64 encoded password to plain text.")
                 password = base64.b64decode(password).decode('utf-8')
             auth_type = "plain"
         cli = AdminCli(args.host, args.user, password, args.verbose,
                        args.debug, api_version=api_version,
                        verify=getattr(args, 'verify', True),
-                      auth_type=auth_type)
+                       auth_type=auth_type)
         if args.base_url:
             cli.base_url = args.base_url
         return cli
@@ -113,6 +116,8 @@ class RawCommand(DefaultCommand):
         super(RawCommand, self).__call__(args)
         self.verbose = args.verbose
         self.debug = args.debug
+        if args.jq:
+            self.log.setLevel(logging.ERROR)
         self.log.info("Begin of raw command.")
         core = self.ls.raw.core
         trace_session(core.session)
@@ -141,15 +146,33 @@ class RawCommand(DefaultCommand):
             trace_request(request)
             last_req_time = str(endtime - starttime)
             content_type = request.headers.get('Content-Type')
+            headers = [
+                'Total-Elements',
+                'Total-Pages',
+                'Current-Page',
+                'Current-Page-Size',
+                'First',
+                'Last'
+            ]
+            for header in headers:
+                value = request.headers.get(header)
+                if value:
+                    self.log.info(header + ": " + str(value))
             if content_type == 'application/json':
                 res = core.process_request(request, url)
                 self.log.debug("res: %s", res)
                 if args.output:
                     with open(args.output, 'w') as file_stream:
-                        json.dump(res, file_stream, sort_keys=True, indent=2, ensure_ascii=False)
-                else:
+                        json.dump(res, file_stream, sort_keys=True, indent=2,
+                                  ensure_ascii=False)
+                elif not args.silent:
                     self.log.info("result: %s",
-                                  json.dumps(res, sort_keys=True, indent=2, ensure_ascii=False))
+                                  json.dumps(res, sort_keys=True, indent=2,
+                                             ensure_ascii=False))
+                if args.jq:
+                    print(json.dumps(res, sort_keys=True, ensure_ascii=False))
+                if args.verbose:
+                    self.log.info("Count: %s", len(res))
             else:
                 if args.output:
                     with open(args.output, 'wb') as file_stream:
@@ -157,7 +180,9 @@ class RawCommand(DefaultCommand):
                             if line:
                                 file_stream.write(line)
                 else:
-                    self.log.warning("Can not process this query, unhandled result content type: %s", content_type)
+                    self.log.warning("Can not process this query !")
+                    self.log.warning(
+                            "Unhandled result content type: %s", content_type)
                     self.log.warning("data: %s", request.text)
             self.log.info(
                 "url:%(cpt)s:%(url)s:request time: %(time)s",
@@ -201,13 +226,21 @@ def add_parser(subparsers, name, desc, config):
 
     parser = subparsers.add_parser('raw', add_help=True)
     parser.add_argument('url')
-    parser.add_argument('-r', '--repeat', default=1, help="default=1", type=int)
+    parser.add_argument(
+            '-r', '--repeat', default=1,
+            help="default=1", type=int)
     parser.add_argument(
         '-m', '--method',
         choices=["GET", "POST", "DELETE", "HEAD", "OPTIONS", "PUT"])
     parser.add_argument('--data')
     parser.add_argument('-H', '--header', action="append", dest="headers")
     parser.add_argument('--output')
+    parser.add_argument(
+            '-s', '--silent', action="store_true",
+            help="Do not display the payload")
+    parser.add_argument(
+            '--jq', action="store_true",
+            help="pure json only")
     parser.set_defaults(__func__=RawCommand(config))
 
     parser = subparsers.add_parser('list')
