@@ -33,7 +33,7 @@ from linshareapi.cache import Time
 from linsharecli.admin.core import DefaultCommand
 from linsharecli.common.core import add_list_parser_options
 from linsharecli.common.core import add_delete_parser_options
-from linsharecli.common.actions import CreateAction
+from linsharecli.common.actions import CreateOneAction
 from linsharecli.common.tables import DeleteAction
 from linsharecli.common.tables import TableBuilder
 from argtoolbox import DefaultCompleter as Completer
@@ -45,24 +45,44 @@ from vhatable.filters import PartialOr
 class DomainsCommand(DefaultCommand):
     """For  api >= 1.9"""
     # pylint: disable=too-many-instance-attributes
-    IDENTIFIER = "label"
-    DEFAULT_SORT = "label"
-    RESOURCE_IDENTIFIER = "identifier"
+    IDENTIFIER = "name"
+    DEFAULT_SORT = "name"
+    RESOURCE_IDENTIFIER = "uuid"
 
     DEFAULT_TOTAL = "Domain found : %(count)s"
     MSG_RS_NOT_FOUND = "No domain could be found."
     MSG_RS_DELETED = (
         "%(position)s/%(count)s: "
-        "The domain '%(label)s' (%(identifier)s) was deleted. (%(time)s s)"
+        "The domain '%(name)s' (%(uuid)s) was deleted. (%(time)s s)"
     )
-    MSG_RS_CAN_NOT_BE_DELETED = "The domain '%(label)s'  '%(identifier)s' can not be deleted."
+    MSG_RS_CAN_NOT_BE_DELETED = "The domain '%(name)s'  '%(uuid)s' can not be deleted."
     MSG_RS_CAN_NOT_BE_DELETED_M = "%(count)s domain (s) can not be deleted."
-    MSG_RS_UPDATED = "The domain '%(label)s' (%(identifier)s) was successfully updated."
+    MSG_RS_UPDATED = "The domain '%(name)s' (%(uuid)s) was successfully updated."
     MSG_RS_CREATED = (
-        "The domain '%(label)s' (%(identifier)s) "
+        "The domain '%(name)s' (%(uuid)s) "
         "was successfully created. (%(_time)s s)"
     )
 
+    # pylint: disable=no-self-use
+    def init_old_language_key_before_5(self):
+        DomainsCommand.IDENTIFIER = "label"
+        DomainsCommand.DEFAULT_SORT = "label"
+        DomainsCommand.RESOURCE_IDENTIFIER = "identifier"
+
+        DomainsCommand.DEFAULT_TOTAL = "Domain found : %(count)s"
+        DomainsCommand.MSG_RS_NOT_FOUND = "No domain could be found."
+        DomainsCommand.MSG_RS_DELETED = (
+            "%(position)s/%(count)s: "
+            "The domain '%(label)s' (%(identifier)s) was deleted. (%(time)s s)"
+        )
+        DomainsCommand.MSG_RS_CAN_NOT_BE_DELETED = "The domain '%(label)s'  '%(identifier)s' can not be deleted."
+        DomainsCommand.MSG_RS_CAN_NOT_BE_DELETED_M = "%(count)s domain (s) can not be deleted."
+        DomainsCommand.MSG_RS_UPDATED = "The domain '%(label)s' (%(identifier)s) was successfully updated."
+        DomainsCommand.MSG_RS_CREATED = (
+            "The domain '%(label)s' (%(identifier)s) "
+            "was successfully created. (%(_time)s s)"
+        )
+
     # pylint: disable=no-self-use
     def init_old_language_key(self):
         """For  api >= 1.6 and api <= 1.8"""
@@ -86,6 +106,8 @@ class DomainsCommand(DefaultCommand):
         super(DomainsCommand, self).__call__(args)
         if self.api_version == 0:
             self.init_old_language_key()
+        elif self.api_version < 5:
+            self.init_old_language_key_before_5()
         json_obj = self.ls.domains.list()
         return (v.get(self.RESOURCE_IDENTIFIER)
                 for v in json_obj if v.get(self.RESOURCE_IDENTIFIER).startswith(prefix))
@@ -141,16 +163,42 @@ class DomainsListCommand(DomainsCommand):
         super(DomainsListCommand, self).__call__(args)
         if self.api_version == 0:
             self.init_old_language_key()
+        elif self.api_version < 5:
+            self.init_old_language_key_before_5()
         endpoint = self.ls.domains
         tbu = TableBuilder(self.ls, endpoint, self.DEFAULT_SORT)
-        tbu.add_action('delete', DDeleteAction())
         tbu.load_args(args)
-        tbu.add_custom_cell("currentWelcomeMessage", ComplexCellBuilder('{name} ({uuid:.8})'))
+        if self.api_version < 5:
+            # no need to override default DeleteAction for version upper than 5
+            tbu.add_action('delete', DDeleteAction())
+            tbu.add_custom_cell(
+                "currentWelcomeMessage",
+                ComplexCellBuilder('{name} ({uuid:.8})', '{name} ({uuid})'))
+        else:
+            tbu.add_custom_cell(
+                "domainPolicy",
+                ComplexCellBuilder('{name} ({uuid:.8})', '{name} ({uuid})'))
+            tbu.add_custom_cell(
+                "mailConfiguration",
+                ComplexCellBuilder('{name} ({uuid:.8})', '{name} ({uuid})'))
+            tbu.add_custom_cell(
+                "mimePolicy",
+                ComplexCellBuilder('{name} ({uuid:.8})', '{name} ({uuid})'))
+            tbu.add_custom_cell(
+                "welcomeMessage",
+                ComplexCellBuilder('{name} ({uuid:.8})', '{name} ({uuid})'))
         tbu.add_custom_cell("providers", ProviderCell)
         tbu.add_filters(
             PartialOr(self.IDENTIFIER, args.identifiers, True),
         )
-        return tbu.build().load_v2(endpoint.list()).render()
+        if args.extended and self.api_version >= 5:
+            table = tbu.build().load_v2(endpoint.list())
+            domains = []
+            for row in table.get_raw():
+                domains.append(endpoint.get(row['uuid']))
+            return tbu.build().load_v2(domains).render()
+        else:
+            return tbu.build().load_v2(endpoint.list()).render()
 
     def complete_fields(self, args, prefix):
         """TODO"""
@@ -168,10 +216,12 @@ class DomainsCreateCommand(DomainsCommand):
         super(DomainsCreateCommand, self).__call__(args)
         if self.api_version == 0:
             self.init_old_language_key()
-        if not args.description:
-            args.description = args.identifier
+        elif self.api_version < 5:
+            if not args.description:
+                args.description = args.identifier
+            self.init_old_language_key_before_5()
 
-        act = CreateAction(self, self.ls.domains)
+        act = CreateOneAction(self, self.ls.domains)
         if act.load(args).execute():
             if not args.domain_policy_auto:
                 return True
@@ -276,6 +326,44 @@ class DomainsUpdateCommand(DomainsCommand):
         return self.ls.domains.options_language()
 
 
+class DomainsUpdateV5Command(DomainsCommand):
+    """ Update a domain."""
+
+    def __call__(self, args):
+        super(DomainsUpdateV5Command, self).__call__(args)
+        domain_uuid = getattr(args, self.RESOURCE_IDENTIFIER)
+        resource = self.ls.domains.get(domain_uuid)
+        if resource is None:
+            raise ValueError("Domain uuid not found")
+        rbu = self.ls.domains.get_rbu()
+        rbu.copy(resource)
+        rbu.load_from_args(args)
+        resource = rbu.to_resource()
+        return self._run(
+            self.ls.domains.update,
+            "The following domain '%(uuid)s' was successfully updated",
+            domain_uuid,
+            resource)
+
+    def complete(self, args, prefix):
+        super(DomainsUpdateV5Command, self).__call__(args)
+        json_obj = self.ls.domains.list()
+        return (v.get('identifier')
+                for v in json_obj if v.get('identifier').startswith(prefix))
+
+    def complete_role(self, args, prefix):
+        """ Complete with available role."""
+        # pylint: disable=unused-argument
+        super(DomainsUpdateV5Command, self).__call__(args)
+        return self.ls.domains.options_role()
+
+    def complete_language(self, args, prefix):
+        """ Complete with available language."""
+        # pylint: disable=unused-argument
+        super(DomainsUpdateV5Command, self).__call__(args)
+        return self.ls.domains.options_language()
+
+
 class DomainsDeleteCommand(DomainsCommand):
     """ List all domains."""
 
@@ -288,6 +376,8 @@ class DomainsDeleteCommand(DomainsCommand):
                 args,
                 cli,
                 args.identifier)
+        elif self.api_version < 5:
+            self.init_old_language_key_before_5()
         return self._delete_all(args, cli, args.uuids)
 
 
@@ -458,8 +548,11 @@ def add_parser(subparsers, name, desc, config):
     # command : create
     parser_tmp2 = subparsers2.add_parser(
         'create', help="create domain.")
-    parser_tmp2.add_argument('--label', action="store", help="")
-    parser_tmp2.add_argument('identifier', action="store", help="")
+    if api_version < 5:
+        parser_tmp2.add_argument('--label', action="store", help="")
+        parser_tmp2.add_argument('identifier', action="store", help="")
+    else:
+        parser_tmp2.add_argument('name', action="store", help="")
     parser_tmp2.add_argument(
         '--type', dest="domain_type", action="store", help="",
         required=True).completer = Completer("complete_type")
@@ -491,8 +584,6 @@ def add_parser(subparsers, name, desc, config):
     # command : update
     parser_tmp2 = subparsers2.add_parser(
         'update', help="update domain.")
-    parser_tmp2.add_argument(
-        'identifier', action="store", help="").completer = Completer()
     parser_tmp2.add_argument('--label', action="store", help="")
     parser_tmp2.add_argument('--description', action="store", help="")
     parser_tmp2.add_argument(
@@ -509,7 +600,14 @@ def add_parser(subparsers, name, desc, config):
         '--welcome', dest="current_welcome_message", action="store",
         help="welcome message identifier").completer = Completer(
             "complete_welcome")
-    parser_tmp2.set_defaults(__func__=DomainsUpdateCommand(config))
+    if api_version < 5:
+        parser_tmp2.add_argument(
+            'identifier', action="store", help="").completer = Completer()
+        parser_tmp2.set_defaults(__func__=DomainsUpdateCommand(config))
+    else:
+        parser_tmp2.add_argument(
+            'uuid', action="store", help="").completer = Completer()
+        parser_tmp2.set_defaults(__func__=DomainsUpdateV5Command(config))
 
     # command : delete
     parser_tmp2 = subparsers2.add_parser(
@@ -523,43 +621,51 @@ def add_parser(subparsers, name, desc, config):
         add_delete_parser_options(parser_tmp2)
     parser_tmp2.set_defaults(__func__=DomainsDeleteCommand(config))
 
-    # command : set provider
-    parser_tmp2 = subparsers2.add_parser(
-        'setup', help="configure user provider.")
-    parser_tmp2.add_argument(
-        'identifier', action="store",
-        help="domain identifier").completer = Completer()
-    parser_tmp2.add_argument('--basedn', action="store", help="",
-                             required=True)
-    parser_tmp2.add_argument(
-        '--ldap', dest="ldap", action="store", help="ldap identifier",
-        required=True).completer = Completer("complete_ldap")
-    parser_tmp2.add_argument(
-        '--dpattern', dest="dpattern", action="store",
-        help="domain pattern identifier",
-        required=True).completer = Completer("complete_dpattern")
-    parser_tmp2.set_defaults(__func__=DomainProvidersCreateCommand(config))
+    def add_cmd_set_provider(subparsers2):
+        """command : set provider"""
+        parser_tmp2 = subparsers2.add_parser(
+            'setup', help="configure user provider.")
+        parser_tmp2.add_argument(
+            'identifier', action="store",
+            help="domain identifier").completer = Completer()
+        parser_tmp2.add_argument('--basedn', action="store", help="",
+                                 required=True)
+        parser_tmp2.add_argument(
+            '--ldap', dest="ldap", action="store", help="ldap identifier",
+            required=True).completer = Completer("complete_ldap")
+        parser_tmp2.add_argument(
+            '--dpattern', dest="dpattern", action="store",
+            help="domain pattern identifier",
+            required=True).completer = Completer("complete_dpattern")
+        parser_tmp2.set_defaults(__func__=DomainProvidersCreateCommand(config))
 
-    # command : update provider
-    parser_tmp2 = subparsers2.add_parser(
-        'updateup', help="update user provider.")
-    parser_tmp2.add_argument(
-        'identifier', action="store",
-        help="domain identifier").completer = Completer()
-    parser_tmp2.add_argument('--basedn', action="store", help="")
-    parser_tmp2.add_argument(
-        '--ldap', dest="ldap", action="store",
-        help="ldap identifier").completer = Completer("complete_ldap")
-    parser_tmp2.add_argument(
-        '--dpattern', dest="dpattern", action="store",
-        help="domain pattern identifier").completer = Completer(
-            "complete_dpattern")
-    parser_tmp2.set_defaults(__func__=DomainProvidersUpdateCommand(config))
+    def add_cmd_update_provider(subparsers2):
+        """command : update provider"""
+        parser_tmp2 = subparsers2.add_parser(
+            'updateup', help="update user provider.")
+        parser_tmp2.add_argument(
+            'identifier', action="store",
+            help="domain identifier").completer = Completer()
+        parser_tmp2.add_argument('--basedn', action="store", help="")
+        parser_tmp2.add_argument(
+            '--ldap', dest="ldap", action="store",
+            help="ldap identifier").completer = Completer("complete_ldap")
+        parser_tmp2.add_argument(
+            '--dpattern', dest="dpattern", action="store",
+            help="domain pattern identifier").completer = Completer(
+                "complete_dpattern")
+        parser_tmp2.set_defaults(__func__=DomainProvidersUpdateCommand(config))
 
-    # command : del provider
-    parser_tmp2 = subparsers2.add_parser(
-        'cleanup', help="clean user provider.")
-    parser_tmp2.add_argument(
-        'identifier', action="store",
-        help="domain identifier").completer = Completer()
-    parser_tmp2.set_defaults(__func__=DomainProvidersDeleteCommand(config))
+    def add_cmd_delete_provider(subparsers2):
+        """command : del provider"""
+        parser_tmp2 = subparsers2.add_parser(
+            'cleanup', help="clean user provider.")
+        parser_tmp2.add_argument(
+            'identifier', action="store",
+            help="domain identifier").completer = Completer()
+        parser_tmp2.set_defaults(__func__=DomainProvidersDeleteCommand(config))
+
+    if api_version < 5:
+        add_cmd_set_provider(subparsers2)
+        add_cmd_update_provider(subparsers2)
+        add_cmd_delete_provider(subparsers2)
