@@ -26,9 +26,10 @@
 #
 
 
-
+import traceback
 
 from argparse import RawTextHelpFormatter
+from argcomplete import debug
 from linshareapi.cache import Time
 from argtoolbox import DefaultCompleter as Completer
 from vhatable.filters import PartialOr
@@ -38,8 +39,8 @@ from linsharecli.common.core import add_list_parser_options
 from linsharecli.common.core import add_delete_parser_options
 from linsharecli.common.tables import TableBuilder
 from linsharecli.common.tables import DeleteAction
-from linsharecli.common.actions import CreateAction
-from linsharecli.common.actions import UpdateAction
+from linsharecli.common.actions import CreateOneAction
+from linsharecli.common.actions import UpdateOneAction
 
 
 class DefaultCommand(Command):
@@ -47,28 +48,35 @@ class DefaultCommand(Command):
 
     IDENTIFIER = "creationDate"
 
-    MSG_RS_UPDATED = "The shared space member '%(account)s' (%(uuid)s) was successfully updated."
-    MSG_RS_CREATED = "The shared space member '%(account)s' (%(uuid)s) was successfully created."
+    MSG_RS_UPDATED = (
+        "The shared space member '%(account)s' "
+        "(%(uuid)s) was successfully updated."
+    )
+    MSG_RS_CREATED = (
+        "The shared space member '%(account)s' "
+        "(%(uuid)s) was successfully created."
+    )
 
     CFG_DELETE_MODE = 1
     CFG_DELETE_ARG_ATTR = "ss_uuid"
 
-
     def complete(self, args, prefix):
-        super(DefaultCommand, self).__call__(args)
+        super().__call__(args)
         json_obj = self.ls.shared_spaces.list()
         return (v.get(self.RESOURCE_IDENTIFIER)
-                for v in json_obj if v.get(self.RESOURCE_IDENTIFIER).startswith(prefix))
+                for v in json_obj if v.get(
+                    self.RESOURCE_IDENTIFIER).startswith(prefix))
 
     def complete_shared_spaces(self, args, prefix):
         """TODO"""
-        super(DefaultCommand, self).__call__(args)
+        super().__call__(args)
         json_obj = self.ls.shared_spaces.list()
         return (v.get(self.RESOURCE_IDENTIFIER)
-                for v in json_obj if v.get(self.RESOURCE_IDENTIFIER).startswith(prefix))
+                for v in json_obj if v.get(
+                    self.RESOURCE_IDENTIFIER).startswith(prefix))
 
 
-class SharedSpaceCompleter(object):
+class SharedSpaceCompleter:
     """TODO"""
     # pylint: disable=too-few-public-methods
 
@@ -76,7 +84,6 @@ class SharedSpaceCompleter(object):
         self.config = config
 
     def __call__(self, prefix, **kwargs):
-        from argcomplete import debug
         try:
             debug("\n------------ SharedSpaceCompleter -----------------")
             debug("Kwargs content :")
@@ -90,7 +97,6 @@ class SharedSpaceCompleter(object):
         # pylint: disable=broad-except
         except Exception as ex:
             debug("\nERROR:An exception was caught :" + str(ex) + "\n")
-            import traceback
             traceback.print_exc()
             debug("\n------\n")
             return ["comlete-error"]
@@ -101,7 +107,7 @@ class ListCommand(DefaultCommand):
 
     @Time('linsharecli.shared_spaces', label='Global time : %(time)s')
     def __call__(self, args):
-        super(ListCommand, self).__call__(args)
+        super().__call__(args)
         endpoint = self.ls.shared_spaces.members
         tbu = TableBuilder(self.ls, endpoint, self.DEFAULT_SORT)
         tbu.load_args(args)
@@ -113,6 +119,14 @@ class ListCommand(DefaultCommand):
                 '{name}',
             )
         )
+        tbu.add_custom_cell(
+            "nestedRole",
+            ComplexCellBuilder(
+                '{name}\n({uuid:.8})',
+                '{name} ({uuid:})',
+                '{name}',
+            )
+        )
         tbu.add_custom_cell(
             "account",
             ComplexCellBuilder(
@@ -121,7 +135,9 @@ class ListCommand(DefaultCommand):
                 '{name}',
             )
         )
-        tbu.add_custom_cell("node", ComplexCellBuilder('{nodeType}: {name} ({uuid:.8})'))
+        tbu.add_custom_cell(
+                "node",
+                ComplexCellBuilder('{nodeType}: {name} ({uuid:.8})'))
         tbu.add_action('delete', DeleteAction(
             mode=self.CFG_DELETE_MODE,
             parent_identifier=self.CFG_DELETE_ARG_ATTR
@@ -136,7 +152,7 @@ class ListCommand(DefaultCommand):
     def complete_fields(self, args, prefix):
         """TODO"""
         # pylint: disable=unused-argument
-        super(ListCommand, self).__call__(args)
+        super().__call__(args)
         cli = self.ls.shared_spaces
         return cli.get_rbu().get_keys(True)
 
@@ -146,8 +162,20 @@ class CreateCommand(DefaultCommand):
 
     @Time('linsharecli.shared_spaces', label='Global time : %(time)s')
     def __call__(self, args):
-        super(CreateCommand, self).__call__(args)
-        act = CreateAction(self, self.ls.shared_spaces.members)
+        super().__call__(args)
+        act = CreateOneAction(self, self.ls.shared_spaces.members)
+        act.load(args)
+        act.rbu.set_value('node', {'uuid': args.ss_uuid})
+        return act.execute()
+
+
+class CreateDriveCommand(DefaultCommand):
+    """TODO"""
+
+    @Time('linsharecli.shared_spaces', label='Global time : %(time)s')
+    def __call__(self, args):
+        super().__call__(args)
+        act = CreateOneAction(self, self.ls.shared_spaces.members.drives)
         act.load(args)
         act.rbu.set_value('node', {'uuid': args.ss_uuid})
         return act.execute()
@@ -158,7 +186,7 @@ class DeleteCommand(DefaultCommand):
 
     @Time('linsharecli.shared_spaces', label='Global time : %(time)s')
     def __call__(self, args):
-        super(DeleteCommand, self).__call__(args)
+        super().__call__(args)
         act = DeleteAction(
             mode=self.CFG_DELETE_MODE,
             parent_identifier=self.CFG_DELETE_ARG_ATTR
@@ -172,14 +200,14 @@ class UpdateCommand(DefaultCommand):
 
     @Time('linsharecli.shared_spaces', label='Global time : %(time)s')
     def __call__(self, args):
-        super(UpdateCommand, self).__call__(args)
+        super().__call__(args)
         self.check_required_options(
             args,
             ['role'],
             ["--role"])
         endpoint = self.ls.shared_spaces.members
         node = endpoint.get(args.ss_uuid, args.uuid)
-        act = UpdateAction(self, endpoint)
+        act = UpdateOneAction(self, endpoint)
         rbu = endpoint.get_rbu()
         rbu.copy(node)
         rbu.load_from_args(args)
@@ -199,7 +227,7 @@ def add_parser(subparsers, name, desc, config):
     parser = subparsers2.add_parser(
         'list',
         formatter_class=RawTextHelpFormatter,
-        help="list shared space from linshare")
+        help="list shared space members of a shared space")
     parser.add_argument(
         'accounts', nargs="*",
         help="Filter documents by their account names")
@@ -212,24 +240,46 @@ def add_parser(subparsers, name, desc, config):
 
     # command : create
     parser = subparsers2.add_parser(
-        'create', help="create shared space.")
+        'create', help="create shared space member for Workgroup")
     parser.add_argument('account', action="store", help="Account uuid")
-    parser.add_argument('--role', action="store",
-                        choices=['ADMIN', 'WRITER', 'CONTRIBUTOR', 'READER'],
-                        help="")
+    choices = ['ADMIN', 'WRITER', 'CONTRIBUTOR', 'READER']
+    parser.add_argument(
+            '--role', action="store",
+            choices=choices,
+            help="")
     parser.add_argument('--cli-mode', action="store_true", help="")
     parser.set_defaults(__func__=CreateCommand(config))
 
+    # command : create-drive
+    api_version = config.server.api_version.value
+    if api_version >= 4.2:
+        parser = subparsers2.add_parser(
+            'create-drive', help="create shared space member for Drive.")
+        parser.add_argument('account', action="store", help="Account uuid")
+        choices=['DRIVE_ADMIN', 'DRIVE_WRITER', 'DRIVE_READER'],
+        if api_version >= 5:
+            choices=['WORKSPACE_ADMIN', 'WORKSPACE_WRITER', 'WORKSPACE_READER'],
+        parser.add_argument(
+                '--role', action="store",
+                choices=choices,
+                help="Drive role")
+        parser.add_argument(
+                '--nested-role', action="store",
+                choices=['ADMIN', 'WRITER', 'CONTRIBUTOR', 'READER'],
+                help="Nested role (default workgroup role)")
+        parser.add_argument('--cli-mode', action="store_true", help="")
+        parser.set_defaults(__func__=CreateDriveCommand(config))
+
     # command : delete
     parser = subparsers2.add_parser(
         'delete',
-        help="delete shared space")
+        help="delete shared space member")
     add_delete_parser_options(parser)
     parser.set_defaults(__func__=DeleteCommand(config))
 
     # command : update
     parser = subparsers2.add_parser(
-        'update', help="update shared space.")
+        'update', help="update shared space member.")
     parser.add_argument(
         'uuid', action="store", help="").completer = Completer()
     parser.add_argument('--role', action="store",
