@@ -32,10 +32,11 @@ from argtoolbox import DefaultCompleter as Completer
 from linshareapi.cache import Time
 from vhatable.filters import PartialOr
 from linsharecli.user.core import DefaultCommand as Command
-from linsharecli.common.actions import CreateAction
-from linsharecli.common.actions import UpdateAction
+from linsharecli.common.actions import CreateOneAction
+from linsharecli.common.actions import UpdateOneAction
 from linsharecli.common.core import add_list_parser_options
 from linsharecli.common.core import add_delete_parser_options
+from linsharecli.common.tables import Action
 from linsharecli.common.tables import TableBuilder
 from linsharecli.common.tables import DeleteAction
 
@@ -55,6 +56,26 @@ class DefaultCommand(Command):
                 for v in json_obj if v.get(self.RESOURCE_IDENTIFIER).startswith(prefix))
 
 
+class Breadcrumb(Action):
+    """TODO"""
+
+    display = True
+
+    def init(self, args, cli, endpoint):
+        super(Breadcrumb, self).init(args, cli, endpoint)
+        self.display = not getattr(args, 'no_breadcrumb', False)
+
+    def __call__(self, args, cli, endpoint, data):
+        self.init(args, cli, endpoint)
+        if self.display:
+            drive_uuid = getattr(args, 'drive', None)
+            if drive_uuid:
+                node = endpoint.get(drive_uuid)
+                print()
+                print("###>", node['name'])
+                print()
+
+
 class ListCommand(DefaultCommand):
     """ List all shared_spaces store into LinShare."""
 
@@ -68,7 +89,12 @@ class ListCommand(DefaultCommand):
             PartialOr(self.IDENTIFIER, args.names, True),
             PartialOr(self.RESOURCE_IDENTIFIER, args.uuids, True)
         )
-        return tbu.build().load_v2(endpoint.list()).render()
+        tbu.add_pre_render_class(Breadcrumb())
+        if self.config.server.api_version.value >= 4.2:
+            return tbu.build().load_v2(endpoint.list(
+                drive=args.drive)).render()
+        else:
+            return tbu.build().load_v2(endpoint.list()).render()
 
     def complete_fields(self, args, prefix):
         """TODO"""
@@ -123,7 +149,7 @@ class UpdateCommand(DefaultCommand):
             ["--name"])
         endpoint = self.ls.shared_spaces
         node = endpoint.get(args.uuid)
-        act = UpdateAction(self, endpoint)
+        act = UpdateOneAction(self, endpoint)
         rbu = endpoint.get_rbu()
         rbu.copy(node)
         rbu.load_from_args(args)
@@ -136,7 +162,7 @@ class CreateCommand(DefaultCommand):
     @Time('linsharecli.shared_spaces', label='Global time : %(time)s')
     def __call__(self, args):
         super(CreateCommand, self).__call__(args)
-        act = CreateAction(self, self.ls.shared_spaces)
+        act = CreateOneAction(self, self.ls.shared_spaces)
         act.load(args)
         return act.execute()
 
@@ -145,14 +171,23 @@ def add_parser(subparsers, name, desc, config):
     """TODO"""
     parser_tmp = subparsers.add_parser(name, help=desc)
     subparsers2 = parser_tmp.add_subparsers()
+    api_version = config.server.api_version.value
 
     # command : list
     parser = subparsers2.add_parser(
         'list',
         formatter_class=RawTextHelpFormatter,
         help="list shared space from linshare")
-    parser.add_argument('names', nargs="*", help="")
-    parser.add_argument('-u', '--uuids', nargs="*", help="")
+    parser.add_argument('names', nargs="*",
+                        help="Filter shared spaces by uuid")
+    if api_version >= 4.2:
+        parser.add_argument(
+            '-d', '--drive', help="Filter shared spaces by uuid")
+        parser.add_argument(
+            '--no-breadcrumb', action="store_true",
+            help="Do not display breadcrumb.")
+    parser.add_argument(
+        '-u', '--uuids', nargs="*", help="Filter shared spaces by uuid")
     add_list_parser_options(parser, delete=True, cdate=True)
     parser.set_defaults(__func__=ListCommand(config))
 
