@@ -39,8 +39,8 @@ from linsharecli.common.core import add_list_parser_options
 from linsharecli.common.core import add_delete_parser_options
 from linsharecli.common.core import add_download_parser_options
 from linsharecli.user.core import DefaultCommand
-from linsharecli.common.actions import CreateAction
-from linsharecli.common.actions import UpdateAction
+from linsharecli.common.actions import CreateOneAction
+from linsharecli.common.actions import UpdateOneAction
 from linsharecli.common.tables import TableBuilder
 from linsharecli.common.tables import Action
 from linsharecli.common.tables import DeleteAction
@@ -457,7 +457,7 @@ class FolderCreateCommand(WgNodesCommand):
     def __call__(self, args):
         super(FolderCreateCommand, self).__call__(args)
         cli = self.ls.workgroup_folders
-        act = CreateAction(self, cli)
+        act = CreateOneAction(self, cli)
         rbu = cli.get_rbu()
         rbu.load_from_args(args)
         if args.folders:
@@ -479,7 +479,7 @@ class NodeUpdateCommand(WgNodesCommand):
         cli = self.ls.workgroup_folders
         uuid = get_uuid_from(args.nodes[-1])
         node = cli.get(args.wg_uuid, uuid)
-        act = UpdateAction(self, cli)
+        act = UpdateOneAction(self, cli)
         rbu = cli.get_rbu()
         rbu.copy(node)
         rbu.load_from_args(args)
@@ -488,7 +488,7 @@ class NodeUpdateCommand(WgNodesCommand):
         return act.load(args).execute(rbu.to_resource())
 
 
-def add_parser(subparsers, name, desc, config):
+def _add_parser(subparsers, name, desc, config):
     """TODO"""
     parser_tmp = subparsers.add_parser(name, help=desc)
     parser_tmp.add_argument(
@@ -603,3 +603,17 @@ def add_parser(subparsers, name, desc, config):
                         a script, by returning only identifiers or numbers
                         without any information messages.""")
     parser.set_defaults(__func__=NodeUpdateCommand(config))
+
+
+def add_parser(subparsers, name, desc, config):
+    """TODO"""
+    api_version = config.server.api_version.value
+    if api_version < 4:
+        _add_parser(subparsers, name, desc, config)
+
+
+def add_parser_v4(subparsers, name, desc, config):
+    """TODO"""
+    api_version = config.server.api_version.value
+    if api_version >= 4:
+        _add_parser(subparsers, name, desc, config)
