@@ -33,7 +33,7 @@ from vhatable.filters import PartialOr
 from linsharecli.user.core import DefaultCommand
 from linsharecli.common.core import add_list_parser_options
 from linsharecli.common.core import add_delete_parser_options
-from linsharecli.common.actions import CreateAction
+from linsharecli.common.actions import CreateOneAction
 from linsharecli.common.tables import TableBuilder
 from linsharecli.common.tables import DeleteAction
 
@@ -79,7 +79,7 @@ class ThreadsCreateCommand(ThreadsCommand):
     @Time('linsharecli.threads', label='Global time : %(time)s')
     def __call__(self, args):
         super(ThreadsCreateCommand, self).__call__(args)
-        act = CreateAction(self, self.ls.threads)
+        act = CreateOneAction(self, self.ls.threads)
         return act.load(args).execute()
 
 
@@ -113,6 +113,9 @@ class ThreadsDeleteCommand(ThreadsCommand):
 
 def add_parser(subparsers, name, desc, config):
     """TODO"""
+    api_version = config.server.api_version.value
+    if api_version >= 4:
+        return
     parser_tmp = subparsers.add_parser(name, help=desc)
 
     subparsers2 = parser_tmp.add_subparsers()
